@@ -1,6 +1,10 @@
 use strict;
 use warnings;
 
+use lib qw(../../../lib);
+
+=encoding utf8
+
 =head1 NAME
 
     Algorithm::Evolutionary::Individual::String - A character string to be evolved. Useful mainly in word games
@@ -25,19 +29,10 @@ use warnings;
 
     my $indi5 = $indi4->clone(); #Creates a copy of the individual
 
-    my @array = qw( a x q W z ); #Tie a String individual
+    my @array = qw( a x q W z ñ); #Tie a String individual
     tie my @vector, 'Algorithm::Evolutionary::Individual::String', @array;
-    print tied( @vector )->asXML();
     
     print $indi3->as_string(); #Prints the individual
-    print $indi3->asXML(); #Prints it as XML. See 
-
-    my $xml=<<EOC;
-<indi type='String'>
-    <atom>a</atom><atom>z</atom><atom>q</atom><atom>i</atom><atom>h</atom>
-</indi>
-EOC
-    $indi4=  Algorithm::Evolutionary::Individual::String->fromXML( $xml );
 
 =head1 Base Class
 
@@ -56,17 +51,23 @@ package Algorithm::Evolutionary::Individual::String;
 
 use Carp;
 
-our $VERSION =   sprintf "%d.%03d", q$Revision: 3.2 $ =~ /(\d+)\.(\d+)/g; 
+our $VERSION = '3.7';
 
 use base 'Algorithm::Evolutionary::Individual::Base';
 
+=head2 MY_OPERATORS
+
+Known operators that act on this subroutine. Probably will be deprecated, so don't rely on it
+
+=cut
+
 use constant MY_OPERATORS => qw(Algorithm::Evolutionary::Op::Crossover 
 				Algorithm::Evolutionary::Op::QuadXOver
 				Algorithm::Evolutionary::Op::StringRand
 				Algorithm::Evolutionary::Op::Permutation	
 				Algorithm::Evolutionary::Op::IncMutation
 				Algorithm::Evolutionary::Op::ChangeLengthMutation );
- 
+
 =head2 new
 
 Creates a new random string, with fixed initial length, and uniform
@@ -80,8 +81,8 @@ enforced unless the client class does it
 sub new {
   my $class = shift; 
   my $self = Algorithm::Evolutionary::Individual::Base::new( $class );
-  $self->{_chars} = shift || ['a'..'z'];
-  $self->{_length} = shift || 10;
+  $self->{'_chars'} = shift || ['a'..'z'];
+  $self->{'_length'} = shift || 10;
   $self->randomize();
   return $self;
 }
@@ -103,9 +104,9 @@ Assigns random values to the elements
 
 sub randomize {
   my $self = shift; 
-  $self->{_str} = ''; # Reset string
-  for ( my $i = 0; $i <  $self->{_length}; $i ++ ) {
-	$self->{_str} .= $self->{_chars}[ rand( @{$self->{_chars}} ) ];
+  $self->{'_str'} = ''; # Reset string
+  for ( my $i = 0; $i <  $self->{'_length'}; $i ++ ) {
+	$self->{'_str'} .= $self->{'_chars'}[ rand( @{$self->{'_chars'}} ) ];
   }
 }
 
@@ -132,13 +133,17 @@ sub fromString  {
   my $str = shift;
   my $self = Algorithm::Evolutionary::Individual::Base::new( $class );
   $self->{_str} =  $str;
+  my %chars;
+  map ( $chars{$_} = 1, split(//,$str) );
+  my @chars = keys %chars; 
   $self->{_length} = length( $str  );
+  $self->{'_chars'} = \@chars;
   return $self;
 }
 
 =head2 from_string
 
-Similar to a copy ctor; creates a bitstring individual from a string. Will be deprecated soon
+Similar to a copy ctor; creates a bitstring individual from a string. 
 
 =cut
 
@@ -161,26 +166,26 @@ Similar to a copy ctor: creates a new individual from another one
 
 sub clone {
   my $indi = shift || croak "Indi to clone missing ";
-  my $self = Algorithm::Evolutionary::Individual::Base::new( ref $indi );
-  for ( keys %$indi ) {
+  my $self = { '_fitness' => undef };
+  bless $self, ref $indi;
+  for ( qw( _chars _str _length)  ) {
 	$self->{ $_ } = $indi->{$_};
   }
-  $self->{_fitness} = undef;
   return $self;
 }
 
 
 =head2 asString
 
-Prints it
+Returns the individual as a string with the fitness as a suffix.
 
 =cut
 
 sub asString {
   my $self = shift;
-  my $str = $self->{_str} . " -> ";
-  if ( defined $self->{_fitness} ) {
-	$str .=$self->{_fitness};
+  my $str = $self->{'_str'} . " -> ";
+  if ( defined $self->{'_fitness'} ) {
+	$str .=$self->{'_fitness'};
   }
   return $str;
 }
@@ -192,7 +197,7 @@ starts at 0, as usual in Perl arrays.
 
 =cut
 
-sub Atom: lvalue {
+sub Atom {
   my $self = shift;
   my $index = shift;
   if ( @_ ) {
@@ -281,22 +286,6 @@ sub as_string {
     return $self->{_str};
 }
 
-
-=head2 asXML()
-
-Prints it as XML. See L<Algorithm::Evolutionary::XML> for more info on this
-
-=cut
-
-sub asXML {
-  my $self = shift;
-  my $str = $self->SUPER::asXML();
-  my $str2 = "> " .join( "", map( "<atom>$_</atom> ", split( "", $self->{_str} )));
-  $str =~ s/\/>/$str2/e ;
-  return $str."\n</indi>";
-}
-
-
 =head2 Chrom
 
 Sets or gets the variable that holds the chromosome. Not very nice, and
@@ -327,9 +316,4 @@ L<Algorithm::Evolutionary::Individual::BitString|Algorithm::Evolutionary::Indivi
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2010/09/24 08:39:07 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/String.pm,v 3.2 2010/09/24 08:39:07 jmerelo Exp $ 
-  $Author: jmerelo $ 
-  $Revision: 3.2 $
-
 =cut
