@@ -3,32 +3,22 @@ use warnings;
 
 =head1 NAME
 
-Algorithm::Evolutionary::Op::Base - Base class for OPEAL operators;
-operators are any object with the "apply" method, which does things to
-individuals or populations. 
+Algorithm::Evolutionary::Op::Base - Base class for Algorithm::Evolutionary operators,
 
 =head1 SYNOPSIS
 
     my $op = new Algorithm::Evolutionary::Op::Base; #Creates empty op, with rate
 
-    my $xmlStr=<<EOC;
-    <op name='Mutation' type='unary' rate='2'>
-      <param name='probability' value='0.5' />
-    </op>
-    EOC
-
-    my $ref = XMLin($xmlStr);
-    my $op = Algorithm::Evolutionary::Op::Base->fromXML( $ref ); #Takes a hash of parsed XML and turns it into an operator    
-
-    print $op->asXML(); #prints it back in XML shape
-
     print $op->rate();  #application rate; relative number of times it must be applied
     print "Yes" if $op->check( 'Algorithm::Evolutionary::Individual::Bit_Vector' ); #Prints Yes, it can be applied to Bit_Vector individual
     print $op->arity(); #Prints 1, number of operands it can be applied to
 
 =head1 DESCRIPTION
 
-Base class for operators applied to Individuals and Populations and all the rest
+Base class for operators applied to Individuals and Populations and
+all the rest.  An operator is any object with the "apply" method,
+which does things to individuals or populations. It is intendedly
+quite general so that any genetic or population operator can fit in. 
 
 =head1 METHODS
 
@@ -45,7 +35,7 @@ use B::Deparse; #For serializing code
 use Algorithm::Evolutionary::Utils qw(parse_xml);
 
 use Carp;
-our ($VERSION) = ( '$Revision: 3.0 $ ' =~ / (\d+\.\d+)/ ) ;
+our ($VERSION) = ( '$Revision: 3.3 $ ' =~ / (\d+\.\d+)/ ) ;
 our %parameters;
 
 =head2 AUTOLOAD
@@ -82,7 +72,8 @@ sub new {
   carp "Should be called from subclasses" if ( $class eq  __PACKAGE__ );
   my $rate = shift || 1;
   my $hash = shift; #No carp here, some operators do not need specific stuff
-  my $self = { rate => $rate }; # Create a reference
+  my $self = { rate => $rate,
+	       _arity => eval( "\$"."$class"."::ARITY" )}; # Create a reference
   bless $self, $class; # And bless it
   $self->set( $hash ) if $hash ;
   return $self;
@@ -204,20 +195,21 @@ sub asXML {
   } else {
     $str .= " >";
     for ( keys %$self ) {
+      next if !$self->{$_};
       if (!/\brate\b/ ) {
-		my ($paramName) = /_(\w+)/;
-		if ( ! ref $self->{$_}  ) {
-		  $str .= "\n\t<param name='$paramName' value='$self->{$_}' />";
-		} elsif ( ref $self->{$_} eq 'ARRAY' ) {
-		  for my $i ( @{$self->{$_}} ) {
-			$str .= $i->asXML()."\n";
-		  }
-		} elsif ( ref $self->{$_} eq 'CODE' ) {
-		  my $deparse = B::Deparse->new;
-		  $str .="<code type='eval' language='perl'>\n<src><![CDATA[".$deparse->coderef2text($self->{$_})."]]>\n </src>\n</code>";
-		} elsif ( (ref $self->{$_} ) =~ 'Algorithm::Evolutionary' ) { #Composite object, I guess...
-		$str .= $self->{$_}->asXML( $_ );
-		}
+	my ($paramName) = /_(\w+)/;
+	if ( ! ref $self->{$_}  ) {
+	  $str .= "\n\t<param name='$paramName' value='$self->{$_}' />";
+	} elsif ( ref $self->{$_} eq 'ARRAY' ) {
+	  for my $i ( @{$self->{$_}} ) {
+	    $str .= $i->asXML()."\n";
+	  }
+	} elsif ( ref $self->{$_} eq 'CODE' ) {
+	  my $deparse = B::Deparse->new;
+	  $str .="<code type='eval' language='perl'>\n<src><![CDATA[".$deparse->coderef2text($self->{$_})."]]>\n </src>\n</code>";
+	} elsif ( (ref $self->{$_} ) =~ 'Algorithm::Evolutionary' ) { #Composite object, I guess...
+	  $str .= $self->{$_}->asXML( $_ );
+	}
       }
     }
     $str .= "\n</op>";
@@ -281,7 +273,10 @@ sub set {
   }
 }
 
-=head1 Known subclasses
+=head2 Known subclasses
+
+This is quite incomplete. Should be either generated automatically or
+suppressed altogether 
 
 =over 4
 
@@ -311,7 +306,7 @@ L<Algorithm::Evolutionary::Op::Novelty_Mutation>
 
 =item * 
 
-L<Algorithm::Evolutionary::Op::Crossover|Algorithm::Evolutionary::Op:Crossover>
+L<Algorithm::Evolutionary::Op:Crossover>
 
 =item * 
 
@@ -343,28 +338,21 @@ L<Algorithm::Evolutionary::Op::DeltaTerm|Algorithm::Evolutionary::Op::DeltaTerm>
 L<Algorithm::Evolutionary::Op::Easy|Algorithm::Evolutionary::Op::Easy>
 
 =item * 
-L<Algorithm::Evolutionary::Op::FullAlgorithm|Algorithm::Evolutionary::Op::FullAlgorithm>
 
+L<Algorithm::Evolutionary::Op::FullAlgorithm>
 
 
 =back
 
 =head1 See Also
 
-The introduction to the XML format used here,
-L<XML>
+The introduction to the XML format used here, L<XML>
 
 =head1 Copyright
   
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/07/24 08:46:59 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Base.pm,v 3.0 2009/07/24 08:46:59 jmerelo Exp $ 
-  $Author: jmerelo $ 
-  $Revision: 3.0 $
-  $Name $
-
 =cut
 
 "What???";
