@@ -38,11 +38,9 @@ package Algorithm::Evolutionary::Op::CanonicalGA;
 
 use lib qw(../../..);
 
-our $VERSION =   sprintf "%d.1%02d", q$Revision: 3.5 $ =~ /(\d+)\.(\d+)/g; # Hack for avoiding version mismatch
-
+our $VERSION =   '3.6';
 
 use Carp;
-use Clone::Fast qw(clone);
 
 use Algorithm::Evolutionary qw(Wheel
 			       Op::Bitflip
@@ -126,7 +124,6 @@ sub apply ($) {
   @$pop = sort { $b->{_fitness} <=> $a->{_fitness} } @$pop;
 }
 
-
 =head1 SEE ALSO
 
 =over 4
@@ -148,12 +145,6 @@ Probably you will also be able to find a
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2010/03/16 18:39:40 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/CanonicalGA.pm,v 3.5 2010/03/16 18:39:40 jmerelo Exp $ 
-  $Author: jmerelo $ 
-  $Revision: 3.5 $
-  $Name $
-
 =cut
 
 "The truth is out there";
