@@ -5,7 +5,7 @@ use lib qw( ../../../../lib );
 
 =head1 NAME
 
-Algorithm::Evolutionary::Op::RouletteWheel - Fitness-proportional selection, using a roulette wheel
+Algorithm::Evolutionary::Op::RouletteWheel - Fitness-proportional selection, using a roulette wheel.
 
 =head1 SYNOPSIS
 
@@ -23,7 +23,7 @@ Roulette wheel selection tries to select as many copies of the
 individual as it corresponds to its fitness. It is used in the
 canonical GA. Some information on this method of selection can be
 found in
-L<http://www.geatbx.com/docu/algselct.html#nameselectionrws|this GA tutorial>
+L<this GA tutorial|http://www.geatbx.com/docu/algselct.html#nameselectionrws>
 
 =head1 METHODS
 
@@ -32,7 +32,7 @@ L<http://www.geatbx.com/docu/algselct.html#nameselectionrws|this GA tutorial>
 package  Algorithm::Evolutionary::Op::RouletteWheel;
 use Carp;
 
-our ($VERSION) = ( '$Revision: 2.3 $ ' =~ / (\d+\.\d+)/ ) ;
+our $VERSION = '3.1';
 
 use base 'Algorithm::Evolutionary::Op::Selector';
 
@@ -93,12 +93,6 @@ selecting a pool of individuals
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/03/24 17:12:52 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/RouletteWheel.pm,v 2.3 2009/03/24 17:12:52 jmerelo Exp $ 
-  $Author: jmerelo $ 
-  $Revision: 2.3 $
-  $Name $
-
 =cut
 
 "The truth is in there";
